var globals_func =
[
    [ "a", "globals_func.html", null ],
    [ "c", "globals_func_c.html", null ],
    [ "g", "globals_func_g.html", null ],
    [ "h", "globals_func_h.html", null ],
    [ "m", "globals_func_m.html", null ],
    [ "p", "globals_func_p.html", null ],
    [ "r", "globals_func_r.html", null ],
    [ "s", "globals_func_s.html", null ],
    [ "v", "globals_func_v.html", null ]
];